==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Dhënia e elementëve të kërkuar dështoi. Verifikoni që kyçi dhe e fshehta juaj për aplikacionin janë të sakta.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Dhënia e elementëve të hyrjes dështoi. Verifikoni që kyçi dhe e fshehta juaj për aplikacionin janë të sakta.",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Step 1 failed. Exception: %s" : "Hapi 1 dështoi. Përjashtim: %s",
    "Step 2 failed. Exception: %s" : "Hapi 2 dështoi. Përjashtim: %s",
    "External storage" : "Depozitë e jashtme",
    "Dropbox App Configuration" : "Formësim i Aplikacionit Dropbox",
    "Google Drive App Configuration" : "Formësim i Aplikacionit Google Drive",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "All users. Type to select user or group." : "Krejt përdoruesit. Shtypni që të përzgjidhet përdorues ose grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Çaktivizimi i depozitës së jashtme do të sjellë çmontimin e krejt depozitave për krejt përdoruesit, jeni i sigurt?",
    "Disable external storage" : "Çaktivizo depozitë të jashtme",
    "Empty response from the server" : "Përgjigje e zbrazët prej shërbyesit",
    "Couldn't access. Please logout and login to activate this mount point" : "S’fut dot. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "S’u morën dot të dhëna nga shërbyesi ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "External mount error" : "Gabim i jashtëm montimi",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Disa nga pikat e jashtme të formësuara të montimit s’janë të lidhura. Ju lutemi, klikoni në shigjetën(at) e kuqe për më tepër të dhëna",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Save" : "Ruaje",
    "Storage with id \"%i\" not found" : "S’u gjet depozitë me id \"%i\"",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Depozita me id \"%i\" s’është e përpunueshme nga përdoruesi",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "URL pikë fundore identiteti",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Strehë",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Ndajeni me të tjerët",
    "Domain" : "Përkatësi",
    "SMB / CIFS using OC login" : "SMB / CIFS me përdorim hyrjeje OC",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë Objektesh OpenStack",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "<b>Note:</b> " : "<b>Shënim:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Shënim:</b> S’është aktivizuar ose instaluar mbulimi i cURL-ve në PHP. Montimi i %s s’është i mundur. Ju lutemi, kërkojini përgjegjësit të sistemit tuaj ta instalojë.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Shënim:</b> S’është instaluar \"%s\". Montimi i %s s’është i mundur. Ju lutemi, kërkojini përgjegjësit të sistemit tuaj ta instalojë.",
    "No external storage configured" : "Pa depozita të jashtme të formësuara",
    "You can add external storages in the storage settings" : "Depozita të jashtme mund të shtoni që prej rregullimeve mbi depozitat",
    "Name" : "Emër",
    "Storage type" : "Lloj depozite",
    "Scope" : "Shtrirje",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "External Storage" : "Depozitë e Jashtme",
    "Enable external storage" : "Aktivizo depozitë të jashtme",
    "External storage has been disabled by the administrator" : "Depozita e jashtme është çaktivizuar nga përgjegjësi",
    "Folder name" : "Emër dosjeje",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Delete" : "Fshije",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme",
    "Allow users to mount the following external storage" : "Lejoju përdoruesve të montojnë depozitën e jashtme vijuese"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/sq.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Dhënia e elementëve të kërkuar dështoi. Verifikoni që kyçi dhe e fshehta juaj për aplikacionin janë të sakta.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Dhënia e elementëve të hyrjes dështoi. Verifikoni që kyçi dhe e fshehta juaj për aplikacionin janë të sakta.",
    "Please provide a valid app key and secret." : "Ju lutemi jepni një kyç dhe një të fshehtë aplikacioni të vlefshme.",
    "Step 1 failed. Exception: %s" : "Hapi 1 dështoi. Përjashtim: %s",
    "Step 2 failed. Exception: %s" : "Hapi 2 dështoi. Përjashtim: %s",
    "External storage" : "Depozitë e jashtme",
    "Dropbox App Configuration" : "Formësim i Aplikacionit Dropbox",
    "Google Drive App Configuration" : "Formësim i Aplikacionit Google Drive",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Grant access" : "Akordoji hyrje",
    "Error configuring OAuth1" : "Gabim gjatë formësimit të OAuth1",
    "Error configuring OAuth2" : "Gabim gjatë formësimit të OAuth2",
    "Generate keys" : "Prodho kyçe",
    "Error generating key pair" : "Gabim gjatë prodhimit të çiftit të kyçeve",
    "All users. Type to select user or group." : "Krejt përdoruesit. Shtypni që të përzgjidhet përdorues ose grup.",
    "(group)" : "(grup)",
    "Compatibility with Mac NFD encoding (slow)" : "Pëerputhshmëri me kodim Mac NFD (e ngadaltë)",
    "Admin defined" : "Përcaktuar nga përgjegjësi",
    "Saved" : "U ruajt",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Çaktivizimi i depozitës së jashtme do të sjellë çmontimin e krejt depozitave për krejt përdoruesit, jeni i sigurt?",
    "Disable external storage" : "Çaktivizo depozitë të jashtme",
    "Empty response from the server" : "Përgjigje e zbrazët prej shërbyesit",
    "Couldn't access. Please logout and login to activate this mount point" : "S’fut dot. Ju lutemi, dilni dhe hyni që të aktivizohet kjo pikë montimi",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "S’u morën dot të dhëna nga shërbyesi ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "S’u mor dot lista e pikave të jashtme të montimit: {type}",
    "There was an error with message: " : "Pati një gabim me këtë mesazh:",
    "External mount error" : "Gabim i jashtëm montimi",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "S’u mor dot lista e pikave të montimit Windows network drive: përgjigje e zbrazët nga shërbyesi",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Disa nga pikat e jashtme të formësuara të montimit s’janë të lidhura. Ju lutemi, klikoni në shigjetën(at) e kuqe për më tepër të dhëna",
    "Please enter the credentials for the {mount} mount" : "Ju lutemi, jepni kredencialet për pikën e montimit {mount}",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Credentials saved" : "Kredencialet u ruajtën",
    "Credentials saving failed" : "Ruajtja e kredencialeve dështoi",
    "Credentials required" : "Lypsen kredenciale",
    "Save" : "Ruaje",
    "Storage with id \"%i\" not found" : "S’u gjet depozitë me id \"%i\"",
    "Invalid backend or authentication mechanism class" : "Mekanizëm shërbimi ose klasë mekanizmi mirëfilltësimi e palvefshme",
    "Invalid mount point" : "Pikë montimi e pavlefshme",
    "Objectstore forbidden" : "Objectstore e ndaluar",
    "Invalid storage backend \"%s\"" : "Mekanizëm shërbimi depozite i pavlefshëm \"%s\"",
    "Not permitted to use backend \"%s\"" : "I palejuar të përdorë mekanizmin e shërbimit \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "S’i lejohet të përdorë mekanizmin e mirëfilltësimit \"%s\"",
    "Unsatisfied backend parameters" : "Parametra mekanizmi shërbimi të paplotësuar",
    "Unsatisfied authentication mechanism parameters" : "Parametra mekanizmi mirëfilltësimi të papërmbushur",
    "Insufficient data: %s" : "Të dhëna të pamjaftueshme: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Depozita me id \"%i\" s’është e përpunueshme nga përdoruesi",
    "Access key" : "Kyç hyrjesh",
    "Secret key" : "Kyç i fshehtë",
    "OAuth1" : "OAuth1",
    "App key" : "Kyç aplikacioni",
    "App secret" : "E fshehtë aplikacioni",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Emër qiraxhiu",
    "Identity endpoint URL" : "URL pikë fundore identiteti",
    "Rackspace" : "Rackspace",
    "API key" : "Kyç API",
    "RSA public key" : "Kyç publik RSA ",
    "Public key" : "Kyç publik",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Strehëemër",
    "Port" : "Portë",
    "Region" : "Rajon",
    "Enable SSL" : "Aktivizo SSL-në",
    "Enable Path Style" : "Aktivizo Stile Shtegu",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Nëndosje e largët",
    "Secure https://" : "https:// e sigurt",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Vendore",
    "Location" : "Vendndodhje",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Strehë",
    "Root" : "Rrënjë",
    "SFTP with secret key login" : "SFTP me hyrje me kyç të fshehtë",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Ndajeni me të tjerët",
    "Domain" : "Përkatësi",
    "SMB / CIFS using OC login" : "SMB / CIFS me përdorim hyrjeje OC",
    "Username as share" : "Emër përdoruesi si emër ndarjeje",
    "OpenStack Object Storage" : "Depozitë Objektesh OpenStack",
    "Service name" : "Emër shërbimi",
    "Request timeout (seconds)" : "Kohë skadimi kërkese (sekonda)",
    "<b>Note:</b> " : "<b>Shënim:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Shënim:</b> S’është aktivizuar ose instaluar mbulimi i cURL-ve në PHP. Montimi i %s s’është i mundur. Ju lutemi, kërkojini përgjegjësit të sistemit tuaj ta instalojë.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Shënim:</b> S’është instaluar \"%s\". Montimi i %s s’është i mundur. Ju lutemi, kërkojini përgjegjësit të sistemit tuaj ta instalojë.",
    "No external storage configured" : "Pa depozita të jashtme të formësuara",
    "You can add external storages in the storage settings" : "Depozita të jashtme mund të shtoni që prej rregullimeve mbi depozitat",
    "Name" : "Emër",
    "Storage type" : "Lloj depozite",
    "Scope" : "Shtrirje",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Enable previews" : "Aktivizoni paraparje",
    "Enable sharing" : "Aktivizo ndarjet",
    "Check for changes" : "Kontrollo për ndryshime",
    "Never" : "Kurrë",
    "Once every direct access" : "Çdo herë pas hyrjesh të drejtpërdrejta",
    "External Storage" : "Depozitë e Jashtme",
    "Enable external storage" : "Aktivizo depozitë të jashtme",
    "External storage has been disabled by the administrator" : "Depozita e jashtme është çaktivizuar nga përgjegjësi",
    "Folder name" : "Emër dosjeje",
    "Authentication" : "Mirëfilltësim",
    "Configuration" : "Formësim",
    "Available for" : "E gatshme për",
    "Add storage" : "Shtoni depozitë",
    "Advanced settings" : "Rregullime të mëtejshme",
    "Delete" : "Fshije",
    "Allow users to mount external storage" : "Lejoju përdoruesve të montojnë depozita të jashtme",
    "Allow users to mount the following external storage" : "Lejoju përdoruesve të montojnë depozitën e jashtme vijuese",
    "No URL provided by backend " : "S’u dha URL nga pjesa e brendshme e programit",
    "Please make sure that the app that provides this backend is installed and enabled" : "Ju lutemi, garantoni që aplikacioni që furnizon këtë program është i instaluar dhe i aktivizuar",
    "Allow sharing on user-mounted external storages" : "Lejo ndarje me të tjerë që nga depo të jashtme të montuara nga përdorues",
    "Error getting OAuth2 URL for " : "Gabim në marrje URL-je OAuth2 për"
},
"nplurals=2; plural=(n != 1);");
